# About the theme

The theme is intended for a few projects developed by me, including [PiNN],
[PiNNacle], [TAME], and the [technological notes][technicality] for the TeC
group. Feel free to use the theme and let me know of bugs and suggestions
through the [GitHub issues]. The project is a hobby project, please understand
that support might not be prompt and the functionality/aestheics are
personal choices.

The project takes inspiration from a number of open-source projects, notable the
[miniflux] reader as the initial inspiration, [mkdocs-materials] for its ample
examples of features. The color theme is taken from [Paul Tol][ptol]'s
medium-contrast scheme.

[PiNN]: https://teoroo-cmc.github.io/pinn/
[PiNNAcLe]: https://teoroo-cmc.github.io/pinnacle/
[TAME]: https://teoroo-cmc.github.io/tame/
[technicality]: https://teoroo-cmc.github.io/TeChnicality/
[GitHub issues]: https://github.com/yqshao/mkdocs-flux/issues/
[miniflux]: https://miniflux.app/
[mkdocs-materials]: https://squidfunk.github.io/mkdocs-material/
[ptol]: https://personal.sron.nl/~pault/
